/*
  Copyright © 2010 Harald Sitter <apachelogger@ubuntu.com>

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
  published by the Free Software Foundation; either version 2 of
  the License or (at your option) version 3 or any later version
  accepted by the membership of KDE e.V. (or its successor approved
  by the membership of KDE e.V.), which shall act as a proxy
  defined in Section 14 of version 3 of the license.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "Account.h"

#include <qjson/qobjecthelper.h>

#include "CouchDB.h"
#include "Subscription.h"

namespace UbuntuOne
{
    namespace Api
    {

        class AccountPrivate
        {
        public:
            virtual ~AccountPrivate() {}

            CouchDB *m_couchdb;
            QString m_couchdbRoot;
            QString m_email;
            QString m_firstName;
            qulonglong m_id;
            QString m_lastName;
            QString m_nickname;
            QString m_openid;
            Subscription *m_subscription;
            QString m_username;
        };

        Account::Account(QObject *parent) :
            QObject(parent),
            d_ptr(new AccountPrivate)
        {
            Q_D(Account);

            d->m_couchdb = new CouchDB(this);
            d->m_subscription = new Subscription(this);
        }

        Account::~Account()
        {
            delete d_ptr;
        }

        CouchDB *Account::couchdb() const
        {
            Q_D(const Account);

            return d->m_couchdb;
        }

        void Account::setCouchdb(const QVariantMap &couchdb)
        {
            QJson::QObjectHelper::qvariant2qobject(couchdb,
                                                   this->couchdb());
        }

        QString Account::couchdbRoot() const
        {
            Q_D(const Account);

            return d->m_couchdbRoot;
        }

        void Account::setCouchdbRoot(const QString &couchdbRoot)
        {
            Q_D(Account);

            d->m_couchdbRoot = couchdbRoot;
        }

        QString Account::email() const
        {
            Q_D(const Account);

            return d->m_email;
        }

        void Account::setEmail(const QString &email)
        {
            Q_D(Account);

            d->m_email = email;
        }

        QString Account::firstName() const
        {
            Q_D(const Account);

            return d->m_firstName;
        }

        void Account::setFirstName(const QString &firstName)
        {
            Q_D(Account);

            d->m_firstName = firstName;
        }

        qulonglong Account::id() const
        {
            Q_D(const Account);

            return d->m_id;
        }

        void Account::setId(const qulonglong &id)
        {
            Q_D(Account);

            d->m_id = id;
        }

        QString Account::lastName() const
        {
            Q_D(const Account);

            return d->m_lastName;
        }

        void Account::setLastName(const QString &lastName)
        {
            Q_D(Account);

            d->m_lastName = lastName;
        }

        QString Account::nickname() const
        {
            Q_D(const Account);

            return d->m_nickname;
        }

        void Account::setNickname(const QString &nickname)
        {
            Q_D(Account);

            d->m_nickname = nickname;
        }

        QString Account::openid() const
        {
            Q_D(const Account);

            return d->m_openid;
        }

        void Account::setOpenid(const QString &openid)
        {
            Q_D(Account);

            d->m_openid = openid;
        }

        Subscription *Account::subscription() const
        {
            Q_D(const Account);

            return d->m_subscription;
        }

        void Account::setSubscription(const QVariantMap &subscription)
        {
            QJson::QObjectHelper::qvariant2qobject(subscription,
                                                   this->subscription());
        }

        QString Account::username() const
        {
            Q_D(const Account);

            return d->m_username;
        }

        void Account::setUsername(const QString &username)
        {
            Q_D(Account);

            d->m_username = username;
        }


    } // namespace Api
} // namespace UbuntuOne
