/*
  Copyright © 2010 Harald Sitter <apachelogger@ubuntu.com>

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
  published by the Free Software Foundation; either version 2 of
  the License or (at your option) version 3 or any later version
  accepted by the membership of KDE e.V. (or its successor approved
  by the membership of KDE e.V.), which shall act as a proxy
  defined in Section 14 of version 3 of the license.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef U1_QT_COUCHDB_H
#define U1_QT_COUCHDB_H

#include <QtCore/QObject>

#include "ApiExport.h"

namespace UbuntuOne
{
    namespace Api
    {

        class CouchDBPrivate;

        /**
          CouchDB object as returned from the Ubuntu One REST API.
          This class is more like a container specific for CouchDB data.
        */
        class U1_QT_EXPORT CouchDB : public QObject
        {
            Q_OBJECT

            Q_PROPERTY(QString path READ path WRITE setPath)
            Q_PROPERTY(QString host READ host WRITE setHost)
            Q_PROPERTY(QString root READ root WRITE setRoot)

        public:
            explicit CouchDB(QObject *parent = 0);
            virtual ~CouchDB();

            /**
              Path of the CouchDB.

              @return path of the CouchDB.
            */
            QString path() const;

            /**
              Set the path.

              @parm path path of the CouchDB.
            */
            void setPath(const QString &path);

            /**
              Host of the CouchDB.

              @return hostname.
            */
            QString host() const;

            /**
              Set the host name of the CouchDB.

              @param host hostname.
            */
            void setHost(const QString &host);

            /**
              Root of the CouchDB.

              @return root.
            */
            QString root() const;

            /**
              Set the root of the CouchDB.

              @param root root.
            */
            void setRoot(const QString &root);

        protected:
            CouchDBPrivate *const d_ptr;

        private:
            Q_DISABLE_COPY(CouchDB)
            Q_DECLARE_PRIVATE(CouchDB)
        };

    } // namespace Api
} // namespace UbuntuOne

#endif // COUCHDB_H
