/*
  Copyright © 2010 Harald Sitter <apachelogger@ubuntu.com>

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
  published by the Free Software Foundation; either version 2 of
  the License or (at your option) version 3 or any later version
  accepted by the membership of KDE e.V. (or its successor approved
  by the membership of KDE e.V.), which shall act as a proxy
  defined in Section 14 of version 3 of the license.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "Device.h"

namespace UbuntuOne
{
    namespace Api
    {

        class DevicePrivate
        {
        public:
            virtual ~DevicePrivate() {}
            QString m_description;
            QString m_kind;
            QString m_token;
        };

        Device::Device(QObject *parent) :
            QObject(parent),
            d_ptr(new DevicePrivate)
        {
        }

        Device::~Device()
        {
            delete d_ptr;
        }

        Device::Device(const Device &other) :
            QObject(other.parent()),
            d_ptr(new DevicePrivate)
        {
            *this = other;
        }

        Device &Device::operator=(const Device &other)
        {
            if (this == &other) {
                return *this;
            }

            Q_D(Device);

            d->m_description = other.description();
            d->m_kind = other.kind();
            d->m_token = other.token();

            return *this;
        }

        QString Device::description() const
        {
            Q_D(const Device);

            return d->m_description;
        }

        void Device::setDescription(const QString &description)
        {
            Q_D(Device);

            d->m_description = description;
        }

        QString Device::kind() const
        {
            Q_D(const Device);

            return d->m_kind;
        }

        void Device::setKind(const QString &kind)
        {
            Q_D(Device);

            d->m_kind = kind;
        }

        QString Device::token() const
        {
            Q_D(const Device);

            return d->m_token;
        }

        void Device::setToken(const QString &token)
        {
            Q_D(Device);

            d->m_token = token;
        }

    } // namespace Api
} // namespace UbuntuOne
