/*
  Copyright © 2010 Harald Sitter <apachelogger@ubuntu.com>

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
  published by the Free Software Foundation; either version 2 of
  the License or (at your option) version 3 or any later version
  accepted by the membership of KDE e.V. (or its successor approved
  by the membership of KDE e.V.), which shall act as a proxy
  defined in Section 14 of version 3 of the license.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef U1_QT_API_QUOTA_H
#define U1_QT_API_QUOTA_H

#include <QtCore/QObject>

#include "ApiExport.h"

namespace UbuntuOne
{
    namespace Api
    {

        class QuotaPrivate;

        /**
          Quota object as returned from the Ubuntu One REST API.
          This class is more like a container specific for Quota data.
        */
        class U1_QT_EXPORT Quota : public QObject
        {
            Q_OBJECT

            Q_PROPERTY(qulonglong total READ total WRITE setTotal)
            Q_PROPERTY(qulonglong used READ used WRITE setUsed)

        public:
            explicit Quota(QObject *parent = 0);
            virtual ~Quota();

            /**
              The total amount of available space.

              @return space in bytes.
            */
            qulonglong total() const;

            /**
              Sets the total amount of available space.

              @param total total amount of space in bytes.
            */
            void setTotal(const qulonglong &total);

            /**
              The amount of used space.

              @return space in bytes.
            */
            qulonglong used() const;

            /**
              Sets the used amount of space.

              @param used used amount of space in bytes.
            */
            void setUsed(const qulonglong &used);

        protected:
            QuotaPrivate *const d_ptr;

        private:
            Q_DISABLE_COPY(Quota)
            Q_DECLARE_PRIVATE(Quota)
        };

    } // namespace Api
} // namespace UbuntuOne

#endif // API_QUOTA_H
