/*
  Copyright © 2010 Harald Sitter <apachelogger@ubuntu.com>

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
  published by the Free Software Foundation; either version 2 of
  the License or (at your option) version 3 or any later version
  accepted by the membership of KDE e.V. (or its successor approved
  by the membership of KDE e.V.), which shall act as a proxy
  defined in Section 14 of version 3 of the license.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "FileViewPlugin.h"

#include <KDebug>
#include <KFileItem>
#include <KPluginFactory>
#include <KPluginLoader>

#include "SyncDaemon.h"
#include "SyncDaemonFilesystem.h"

K_PLUGIN_FACTORY(FileViewUbuntuOnePluginFactory, registerPlugin<UbuntuOne::FileViewPlugin>(););
K_EXPORT_PLUGIN(FileViewUbuntuOnePluginFactory("fileviewubuntuoneplugin"));

namespace UbuntuOne
{

    FileViewPlugin::FileViewPlugin(QObject *parent, const QList<QVariant> &args) :
        KVersionControlPlugin(parent),
        fs(0),
        daemon(0)
    {
        Q_UNUSED(args);
    }

    FileViewPlugin::~FileViewPlugin()
    {
    }

    QString FileViewPlugin::fileName() const
    {
        return ".ubuntuone";
    }

    bool FileViewPlugin::beginRetrieval(const QString &directory)
    {
        Q_UNUSED(directory);

        // Make init faster by only calling to the daemon once a u1 folder was
        // opened.
        if (!fs && !daemon) {
            fs = new SyncDaemonFilesystem(this);
            daemon = new SyncDaemon(this);
        }

        daemon->updateStatus();

        return true;
    }

    KVersionControlPlugin::VersionState FileViewPlugin::versionState(const KFileItem &item)
    {
        kDebug() << item;

        switch (fs->fileState(item)) {
        case UbuntuOne::UnknownFileState : return UnversionedVersion; break;
        case UbuntuOne::NeedsUpdateFileState : return UpdateRequiredVersion; break;
        case UbuntuOne::NeedsUploadFileState : return LocallyModifiedVersion; break;
        default : return NormalVersion; break;
        }

        return NormalVersion;
    }

    void FileViewPlugin::endRetrieval()
    {
        fs->deleteLater();
        daemon->deleteLater();
    }

    QList<QAction *> FileViewPlugin::contextMenuActions(const KFileItemList &items)
    {
        Q_UNUSED(items);

        QList<QAction *> actions;
        return actions;
    }

    QList<QAction *> FileViewPlugin::contextMenuActions(const QString &directory)
    {
        Q_UNUSED(directory);

        QList<QAction *> actions;
        return actions;
    }

} // namespace UbuntuOne
