/*
  Copyright © 2010 Harald Sitter <apachelogger@ubuntu.com>

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
  published by the Free Software Foundation; either version 2 of
  the License or (at your option) version 3 or any later version
  accepted by the membership of KDE e.V. (or its successor approved
  by the membership of KDE e.V.), which shall act as a proxy
  defined in Section 14 of version 3 of the license.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "ConfigWidget.h"
#include "ui_ConfigWidget.h"

static const int CONVERSION_UNIT = 1024;

namespace UbuntuOne {

    ConfigWidget::ConfigWidget(QWidget *parent) :
            QWidget(parent),
            ui(new Ui::ConfigWidget)
    {
        ui->setupUi(this);

        connect(ui->m_bandwithBox, SIGNAL(toggled(bool)), this, SIGNAL(changed()));
        connect(ui->m_upSpin, SIGNAL(valueChanged(int)), this, SIGNAL(changed()));
        connect(ui->m_downSpin, SIGNAL(valueChanged(int)), this, SIGNAL(changed()));
        connect(ui->m_autostartNotifier, SIGNAL(toggled(bool)), this, SIGNAL(changed()));
    }

    ConfigWidget::~ConfigWidget()
    {
        delete ui;
    }

    bool ConfigWidget::isThrottling() const
    {
        return ui->m_bandwithBox->isChecked();
    }

    void ConfigWidget::setThrottling(bool enabled)
    {
        ui->m_bandwithBox->setChecked(enabled);
    }

    SyncDaemonConfig::ThrottlingLimits ConfigWidget::throttlingLimits() const
    {
        SyncDaemonConfig::ThrottlingLimits limits;
        limits.upload = ui->m_upSpin->value() * CONVERSION_UNIT;
        limits.download = ui->m_downSpin->value() * CONVERSION_UNIT;
        return limits;
    }

    void ConfigWidget::setThrottlingLimits(SyncDaemonConfig::ThrottlingLimits limits)
    {
        if (limits.upload != -1) {
            ui->m_upSpin->setValue(limits.upload / CONVERSION_UNIT);
        }
        if (limits.download != -1) {
            ui->m_downSpin->setValue(limits.download / CONVERSION_UNIT);
        }
    }

    void ConfigWidget::setThrottlingLimits(int upload, int download)
    {
        ui->m_upSpin->setValue(upload / CONVERSION_UNIT);
        ui->m_downSpin->setValue(download / CONVERSION_UNIT);
    }

    bool ConfigWidget::autostart() const
    {
        return ui->m_autostartNotifier->isChecked();
    }

    void ConfigWidget::setAutostart(bool enabled)
    {
        ui->m_autostartNotifier->setChecked(enabled);
    }

} // namespace UbuntuOne
