/*
  Copyright © 2010 Harald Sitter <apachelogger@ubuntu.com>

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
  published by the Free Software Foundation; either version 2 of
  the License or (at your option) version 3 or any later version
  accepted by the membership of KDE e.V. (or its successor approved
  by the membership of KDE e.V.), which shall act as a proxy
  defined in Section 14 of version 3 of the license.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef FOLDERMODEL_H
#define FOLDERMODEL_H

#include <QtGui/QFileSystemModel>
#include <QtCore/QSet>

namespace UbuntuOne {
    class SyncDaemon;
    class SyncDaemonFolders;

    class FolderModel : public QFileSystemModel
    {
    public:
        FolderModel();

        virtual Qt::ItemFlags flags( const QModelIndex &index ) const;
        QVariant data( const QModelIndex& index, int role = Qt::DisplayRole ) const;
        bool setData( const QModelIndex& index, const QVariant& value, int role = Qt::EditRole );

        void setDirectories( const QStringList &dirs );
        QStringList directories() const;

        virtual int columnCount( const QModelIndex& ) const
        {
            return 1;
        }

    public Q_SLOTS:
        void save();

    private:
        bool ancestorChecked( const QString &path ) const;
        bool descendantChecked( const QString &path ) const;
        bool isForbiddenPath( const QString &path ) const;
        bool recursive() const
        {
            // Ubuntu One is always recursive (at least for the time being).
            return true;
        }
        QSet<QString> m_checked;

        SyncDaemon *m_daemon;
        SyncDaemonFolders *m_folders;
    };
} // namespace UbuntuOne

#endif // FOLDERMODEL_H
