  /*
  Copyright © 2010 Harald Sitter <apachelogger@ubuntu.com>

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
  published by the Free Software Foundation; either version 2 of
  the License or (at your option) version 3 or any later version
  accepted by the membership of KDE e.V. (or its successor approved
  by the membership of KDE e.V.), which shall act as a proxy
  defined in Section 14 of version 3 of the license.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "GeneralModule.h"

#include <QtGui/QVBoxLayout>

#include <KAboutData>
#include <KConfigGroup>
#include <KGenericFactory>
#include <KPluginFactory>

#include "SyncDaemonConfig.h"

#include "ConfigWidget.h"
#include "InfoModule.h"

static const int DEFAULT_BANDWITH = 0;

static const char UBUNTUONE_CFG[] = "ubuntuonerc";
static const char UBUNTUONE_CFG_AUTOSTART_GRP[] = "General";
static const char UBUNTUONE_CFG_AUTOSTART[] = "Autostart";

K_PLUGIN_FACTORY_DECLARATION(KcmUbuntuOneFactory);

namespace UbuntuOne
{
    GeneralModule::GeneralModule(QWidget *parent, const QVariantList &args) :
            KCModule(KcmUbuntuOneFactory::componentData(), parent, args),
            m_config(new SyncDaemonConfig(this)),
            m_configWidget(new ConfigWidget(this)),
            m_info(new InfoModule(this))
    {
        KAboutData *about = new KAboutData(I18N_NOOP("ubuntuone-kcm"), 0,
                                           ki18n("Ubuntu One Configuration module"), "0.1",
                                           KLocalizedString(), KAboutData::License_GPL_V3,
                                           ki18n("Copyright 2010, Harald Sitter apachelogger@ubuntu.com"),
                                           KLocalizedString(),
                                           "");
        about->addAuthor(ki18n("Harald Sitter"), KLocalizedString(),
                         "apachelogger@ubuntu.com");
        setAboutData(about);

        setLayout(new QVBoxLayout(this));
        layout()->addWidget(m_info);

        layout()->addWidget(m_configWidget);

        // TODO: move loadable stuff to load()!
        bool throttling = m_config->isThrottling();
        m_configWidget->setThrottling(throttling);
        if (throttling) {
            m_configWidget->setThrottlingLimits(m_config->throttlingLimits());
        }

        KConfig config(UBUNTUONE_CFG);
        KConfigGroup configGroup(&config, UBUNTUONE_CFG_AUTOSTART_GRP);
        m_configWidget->setAutostart(configGroup.readEntry(UBUNTUONE_CFG_AUTOSTART, false));

        connect(m_configWidget, SIGNAL(changed()), this, SLOT(changed()));
    }

    GeneralModule::~GeneralModule()
    {
    }

    void GeneralModule::load()
    {
    }

    void GeneralModule::save()
    {
        bool throttle = m_configWidget->isThrottling();
        m_config->setThrottling(throttle);
        if (throttle) {
            m_config->setThrottlingLimits(m_configWidget->throttlingLimits());
        }

        KConfig config(UBUNTUONE_CFG);
        KConfigGroup configGroup(&config, UBUNTUONE_CFG_AUTOSTART_GRP);
        configGroup.writeEntry(UBUNTUONE_CFG_AUTOSTART, m_configWidget->autostart());
        config.sync();
    }

    void GeneralModule::defaults()
    {
        m_configWidget->setThrottlingLimits(DEFAULT_BANDWITH, DEFAULT_BANDWITH);
        m_configWidget->setThrottling(false);
        m_configWidget->setAutostart(true);
    }

} // namespace UbuntuOne
