/*
  Copyright © 2010 Harald Sitter <apachelogger@ubuntu.com>

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
  published by the Free Software Foundation; either version 2 of
  the License or (at your option) version 3 or any later version
  accepted by the membership of KDE e.V. (or its successor approved
  by the membership of KDE e.V.), which shall act as a proxy
  defined in Section 14 of version 3 of the license.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "InfoModule.h"

#include <QtGui/QVBoxLayout>

#include <KLocalizedString>
#include <KPluginFactory>
#include <KMessageBox>

#include "Account.h"
#include "Api.h"
#include "Device.h"

#include "InfoWidget.h"

K_PLUGIN_FACTORY_DECLARATION(KcmUbuntuOneFactory)

namespace UbuntuOne {

    InfoModule::InfoModule(QWidget *parent, const QVariantList &args) :
            KCModule(KcmUbuntuOneFactory::componentData(), parent, args),
            m_api(0),
            m_info(new InfoWidget(this))
    {
        setLayout(new QVBoxLayout(this));
        layout()->addWidget(m_info);
    }

    InfoModule::~InfoModule()
    {
    }

    void InfoModule::load()
    {
        if (m_api == 0) {
            m_api= new Api::Interface(this);
            connect(m_api, SIGNAL(ready()),
                    this, SLOT(getData()));
            // TODO: mask widget with Akonadi-like error overlay
            connect(m_api, SIGNAL(authorizationDenied()),
                    this, SLOT(authorizationDenied()));
            connect(m_api, SIGNAL(noCredentials()),
                    this, SLOT(noCredentials()));
            connect(m_api, SIGNAL(oauthError(QString)),
                    this, SLOT(oauthError(QString)));

            connect(m_api, SIGNAL(got(UbuntuOne::Api::Account)),
                    m_info, SLOT(set(UbuntuOne::Api::Account)));
            connect(m_api, SIGNAL(got(UbuntuOne::Api::Quota)),
                    m_info, SLOT(set(UbuntuOne::Api::Quota)));
            connect(m_api, SIGNAL(got(QList<UbuntuOne::Api::Device>)),
                    m_info, SLOT(set(QList<UbuntuOne::Api::Device>)));
            return;
        }
        getData();
    }

    void InfoModule::save()
    {
    }

    void InfoModule::defaults()
    {
    }

    void InfoModule::getData()
    {
        m_api->getAccount();
        m_api->getQuota();
        m_api->getDevices();
    }

    void InfoModule::authorizationDenied()
    {
        KMessageBox::error(this,
                           i18nc("@info error",
                                 "Authorization to access Ubuntu One denied. "
                                 "Without authorization no information can be requested."),
                           i18nc("@title:window", "Authorization Denied"));
    }

    void InfoModule::noCredentials()
    {
        KMessageBox::error(this,
                           i18nc("@info error",
                                 "No credentials could be found. "
                                 "Without credentials login to Ubuntu One is not possible."),
                           i18nc("@title:window", "No Credentials Found"));
    }

    void InfoModule::oauthError(const QString &error)
    {
        KMessageBox::detailedError(this,
                                   i18nc("@info error",
                                         "An OAuth error was received. "
                                         "This usually indicates that the login to Ubuntu One was not successful."),
                                   error,
                                   i18nc("@title:window", "OAuth Error"));
    }

} // namespace UbuntuOne
