/*
  Copyright © 2010 Harald Sitter <apachelogger@ubuntu.com>

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
  published by the Free Software Foundation; either version 2 of
  the License or (at your option) version 3 or any later version
  accepted by the membership of KDE e.V. (or its successor approved
  by the membership of KDE e.V.), which shall act as a proxy
  defined in Section 14 of version 3 of the license.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "InfoWidget.h"
#include "ui_InfoWidget.h"

#include <kcapacitybar.h>
#include <KDebug>
#include <KToolInvocation>

#include "Account.h"
#include "Device.h"
#include "Subscription.h"
#include "Quota.h"

namespace UbuntuOne
{
    InfoWidget::InfoWidget(QWidget *parent) :
            QWidget(parent),
            ui(new Ui::InfoWidget)
    {
        ui->setupUi(this);

        m_stoarge = new KCapacityBar(KCapacityBar::DrawTextOutline, this);
        m_stoarge->setValue(0);
        m_stoarge->hide();
        ui->m_layout->insertWidget(0, m_stoarge); // Insert at top

        ui->m_accountLabel->setText(i18nc("@info",
                                    "<link url='%1'>Manage Account</link>",
                                    "http://one.ubuntu.com/account"));
        connect(ui->m_accountLabel, SIGNAL(linkActivated(QString)),
                this, SLOT(openUrl(QString)));

        ui->m_supportLabel->setText(i18nc("@info",
                                    "<link url='%1'>Support Options</link>",
                                    "http://one.ubuntu.com/support"));
        connect(ui->m_supportLabel, SIGNAL(linkActivated(QString)),
                this, SLOT(openUrl(QString)));
    }

    InfoWidget::~InfoWidget()
    {
        delete ui;
    }

    void InfoWidget::set(const UbuntuOne::Api::Account &account)
    {
        ui->m_name->setText(account.nickname());
        ui->m_mail->setText(account.email());
        ui->m_plan->setText(account.subscription()->description());
    }

    void InfoWidget::set(const UbuntuOne::Api::Quota &quota)
    {
        int percent = ((100 * quota.used()) / quota.total());

        QString used = KGlobal::locale()->formatByteSize(quota.used());
        QString total = KGlobal::locale()->formatByteSize(quota.total());

        m_stoarge->setValue(percent);
        m_stoarge->setToolTip(i18nc("@info:tooltip", "%1 of %2 used", used, total));
        m_stoarge->setText(i18nc("@label", "%1 of %2 used", used, total));
        m_stoarge->show();

        kDebug() << quota.total();
        kDebug() << quota.used();
        kDebug() << "at percent: " << percent;
    }

    void InfoWidget::set(const QList<UbuntuOne::Api::Device> &deviceList)
    {
        foreach (const Api::Device &device, deviceList) {
            ui->devicesLayout->addWidget(new QLabel(device.description(), this));
        }
    }

    void InfoWidget::openUrl(const QString &url)
    {
        KToolInvocation::invokeBrowser(url);
    }
} // namespace UbuntuOne
