/*
Copyright © 2010 Harald Sitter <apachelogger@ubuntu.com>

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License as
published by the Free Software Foundation; either version 2 of
the License or (at your option) version 3 or any later version
accepted by the membership of KDE e.V. (or its successor approved
by the membership of KDE e.V.), which shall act as a proxy
defined in Section 14 of version 3 of the license.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "ShareInfoWidget.h"

#include <QtGui/QGridLayout>
#include <QtGui/QLabel>

#include <KGlobal>
#include <KIcon>
#include <KIconLoader>
#include <KLocale>
#include <KLocalizedString>
#include <KRun>
#include <KUrlLabel>

namespace UbuntuOne {

    ShareInfoWidget::ShareInfoWidget(QWidget *parent) :
            QGroupBox(parent)
    {
        setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Maximum);

        m_layout = new QGridLayout(this);
        m_layout->setAlignment(Qt::AlignTop|Qt::AlignLeft);
        m_layout->setSpacing(10);

        m_iconLabel = new QLabel();
        m_iconLabel->setAlignment(Qt::AlignCenter);
        m_iconLabel->setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Maximum);
        m_iconLabel->setPixmap(KIcon("ubuntuone").pixmap(KIconLoader::SizeHuge));
        m_layout->addWidget(m_iconLabel, 1, 1, 3, 1, Qt::AlignCenter);

        m_pathLabel = new QLabel(i18nc("@label/rich", "<emphasis strong='true'>Path</emphasis>"));
        m_pathValueLabel = new KUrlLabel();
        connect(m_pathValueLabel, SIGNAL(leftClickedUrl(QString)),
                this, SLOT(openUrl(QString)));
        m_layout->addWidget(m_pathLabel, 1, 2, 1, 1);
        m_layout->addWidget(m_pathValueLabel, 1, 3, 1, 1);

        m_sharedWithLabel = new QLabel(i18nc("@label/rich", "<emphasis strong='true'>Shared With</emphasis>"));
        m_sharedWithValueLabel = new QLabel("");
        m_layout->addWidget(m_sharedWithLabel, 2, 2, 1, 1);
        m_layout->addWidget(m_sharedWithValueLabel, 2, 3, 1, 1);

        m_accessLabel = new QLabel(i18nc("@label/rich", "<emphasis strong='true'>Access Level</emphasis>"));
        m_accessValueLabel = new QLabel("");
        m_layout->addWidget(m_accessLabel, 3, 2, 1, 1);
        m_layout->addWidget(m_accessValueLabel, 3, 3, 1, 1);

        m_freeSpaceLabel = new QLabel(i18nc("@label/rich", "<emphasis strong='true'>Unused Space</emphasis>"));
        m_freeSpaceValueLabel = new QLabel("");
        m_layout->addWidget(m_freeSpaceLabel, 4, 2, 1, 1);
        m_layout->addWidget(m_freeSpaceValueLabel, 4, 3, 1, 1);

        // TODO: is accetped

        setLayout(m_layout);
    }

    ShareInfoWidget::~ShareInfoWidget()
    {
    }

    void ShareInfoWidget::setType(Share::Type type)
    {
        if (type == Share::Inbound) {
            m_sharedWithLabel->setText(i18nc("@label/rich", "<emphasis strong='true'>Shared By</emphasis>"));
            m_iconLabel->setPixmap(KIcon("ubuntuone", KIconLoader::global(),
                                         QStringList ("go-down")).pixmap(KIconLoader::SizeHuge));
        } else {
            m_iconLabel->setPixmap(KIcon("ubuntuone", KIconLoader::global(),
                                         QStringList ("go-up")).pixmap(KIconLoader::SizeHuge));
        }
    }

    void ShareInfoWidget::setPath(const QString &path)
    {
        m_pathValueLabel->setText(path);
        m_pathValueLabel->setUrl(path);
    }

    void ShareInfoWidget::setSharedWith(const QString &partner)
    {
        m_sharedWithValueLabel->setText(partner);
    }

    void ShareInfoWidget::setSharedWith(const QStringList &partners)
    {
        m_sharedWithValueLabel->setText(partners.join(QLatin1String(", ")));
    }

    void ShareInfoWidget::setAccess(Share::Access access)
    {
        if (access == Share::Read) {
             m_accessValueLabel->setText("View");
        } else {
             m_accessValueLabel->setText("Write");
        }
    }

    void ShareInfoWidget::setFreeSpace(double freeBytes)
    {
        m_freeSpaceValueLabel->setText(KGlobal::locale()->formatByteSize(freeBytes));
    }

    void ShareInfoWidget::openUrl(const QString &url)
    {
        new KRun(KUrl(url), this);
    }

} // namespace UbuntuOne
