/*
  Copyright © 2010 Harald Sitter <apachelogger@ubuntu.com>

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
  published by the Free Software Foundation; either version 2 of
  the License or (at your option) version 3 or any later version
  accepted by the membership of KDE e.V. (or its successor approved
  by the membership of KDE e.V.), which shall act as a proxy
  defined in Section 14 of version 3 of the license.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "Folder.h"

#include "QtDBus/QDBusMetaType"

#include "Types.h"

namespace UbuntuOne {

    class FolderPrivate
    {
    public:
        bool subscribed;
        QString volumeId;
        QString nodeId;
        QString path;
        Folder::Type type;
        QString suggestedPath;
    };

    Folder::Folder(QObject *parent) :
            QObject(parent),
            d_ptr(new FolderPrivate)
    {
    }

    Folder::~Folder()
    {
    }

    Folder::Folder(const Folder &other) :
        QObject(other.parent()),
        d_ptr(new FolderPrivate)
    {
        *this = other;
    }

    Folder &Folder::operator=(const Folder &other)
    {
        if (this == &other) {
            return *this;
        }

        Q_D(Folder);

        d->subscribed = other.isSubsribed();
        d->volumeId = other.volumeId();
        d->nodeId = other.nodeId();
        d->path = other.path();
        d->type = other.type();
        d->suggestedPath = other.suggestedPath();

        return *this;
    }

    bool Folder::isSubsribed() const
    {
        Q_D(const Folder);
        return d->subscribed;
    }

    QString Folder::volumeId() const
    {
        Q_D(const Folder);
        return d->volumeId;
    }

    QString Folder::nodeId() const
    {
        Q_D(const Folder);
        return d->nodeId;
    }

    QString Folder::path() const
    {
        Q_D(const Folder);
        return d->path;
    }

    Folder::Type Folder::type() const
    {
        Q_D(const Folder);
        return d->type;
    }

    QString Folder::suggestedPath() const
    {
        Q_D(const Folder);
        return d->suggestedPath;
    }

    void Folder::registerMetaType()
    {
        qRegisterMetaType<UbuntuOne::Folder>("UbuntuOne::Folder");
        qDBusRegisterMetaType<UbuntuOne::Folder>();
        qRegisterMetaType<UbuntuOne::FolderList>("UbuntuOne::FolderList");
        qDBusRegisterMetaType<UbuntuOne::FolderList>();
    }

    // TODO: find some way to loop over all elements and (de)serialize that way.
    const QDBusArgument &operator>>(const QDBusArgument &argument,
                                    UbuntuOne::Folder &folder)
    {
        QStringHash myhash;
        argument >> myhash;

        FolderPrivate *const d = folder.d_func();

        d->subscribed = myhash["subscribed"] == QLatin1String("True") ? true : false;
        d->volumeId = myhash["volume_id"];
        d->nodeId = myhash["node_id"];
        d->path = myhash["path"];
        d->type = myhash["type"] == QLatin1String("UDF") ? Folder::UDF : Folder::Unknown;
        d->suggestedPath = myhash["suggested_path"];

        return argument;
    }

    QDBusArgument &operator<<(QDBusArgument &argument, const UbuntuOne::Folder &folder)
    {
        Q_UNUSED(folder);
        // TODO: Implement proper when needed.
        argument.beginMap(QVariant::String, QVariant::String);
        argument.endMap();
        return argument;
    }

} // namespace UbuntuOne
