/*
  Copyright © 2010 Harald Sitter <apachelogger@ubuntu.com>

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
  published by the Free Software Foundation; either version 2 of
  the License or (at your option) version 3 or any later version
  accepted by the membership of KDE e.V. (or its successor approved
  by the membership of KDE e.V.), which shall act as a proxy
  defined in Section 14 of version 3 of the license.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef U1_KDE_FOLDER_H
#define U1_KDE_FOLDER_H

#include <QtCore/QObject>
#include <QtDBus/QDBusArgument>

#include "Export.h"

namespace UbuntuOne {
    class FolderPrivate;

    /**
      A folder synchronized by Ubuntu One.
    */
    class U1_KDE_EXPORT Folder : public QObject
    {
        Q_OBJECT
    public:
        /**
          Type of the folder.
        */
        enum Type
        {
            Unknown = -1,
            UDF = 0
        };

        Folder(QObject *parent = 0);
        virtual ~Folder();

        Folder(const Folder &other);
        Folder &operator=(const Folder &other);

        /**
          Whether the current device is subscribed to this folder. An inactive
          subscription means that the folder, however available on Ubuntu One,
          is not actively synchronized with this device.

          @return true if the current device is subscribed to this folder
        */
        bool isSubsribed() const;

        /**
          The unique volume id of this folder.

          @return volume id
        */
        QString volumeId() const;

        /**
          The unique node id of this folder.

          @return node id
        */
        QString nodeId() const;

        /**
          The path under which this folder is available on the local system.

          @return local path
        */
        QString path() const;

        /**
          The type of this folder.

          @return folder type
        */
        Type type() const;

        /**
          The path which is suggested to be used for this folder locally.

          @return suggested folder path
        */
        QString suggestedPath() const;

        /**
          Registers the folder class with the Qt DBus type system.
        */
        static void registerMetaType();

        friend const QDBusArgument &operator>>(const QDBusArgument &argument,
                                               Folder &folder);
        friend QDBusArgument &operator<<(QDBusArgument &argument,
                                         const Folder &folder);

    protected:
        FolderPrivate *const d_ptr;

    private:
        Q_DECLARE_PRIVATE(Folder)
    };

    typedef QList<Folder> FolderList;
} // namespace UbuntuOne

#endif // FOLDER_H
