/*
  Copyright © 2010 Harald Sitter <apachelogger@ubuntu.com>

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
  published by the Free Software Foundation; either version 2 of
  the License or (at your option) version 3 or any later version
  accepted by the membership of KDE e.V. (or its successor approved
  by the membership of KDE e.V.), which shall act as a proxy
  defined in Section 14 of version 3 of the license.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "SyncDaemonConfig.h"

#include <QtCore/QDebug>

#include "SyncDaemonDBus.h"
#include "Types.h"

namespace UbuntuOne {
    class SyncDaemonConfigPrivate
    {
    public:
        ComUbuntuoneSyncDaemonConfigInterface *config;
    };

    SyncDaemonConfig::SyncDaemonConfig(QObject *parent) :
            QObject(parent),
            d_ptr(new SyncDaemonConfigPrivate)
    {
        qRegisterMetaType<QIntHash>("QIntHash");
        qDBusRegisterMetaType<QIntHash>();

        Q_D(SyncDaemonConfig);

        d->config =
            new ComUbuntuoneSyncDaemonConfigInterface("com.ubuntuone.SyncDaemon",
                    "/config", QDBusConnection::sessionBus(), this);
    }

    SyncDaemonConfig::~SyncDaemonConfig()
    {
        delete d_ptr;
    }

    bool SyncDaemonConfig::fileSync() const
    {
        Q_D(const SyncDaemonConfig);
        return d->config->files_sync_enabled();
    }

    void SyncDaemonConfig::setFileSync(bool sync)
    {
        Q_D(SyncDaemonConfig);
        d->config->set_files_sync_enabled(sync);
    }

    bool SyncDaemonConfig::isThrottling() const
    {
        Q_D(const SyncDaemonConfig);
        return d->config->bandwidth_throttling_enabled();
    }

    void SyncDaemonConfig::setThrottling(bool throttle)
    {
        Q_D(SyncDaemonConfig);
        if (throttle) {
            d->config->enable_bandwidth_throttling();
        } else {
            d->config->disable_bandwidth_throttling();
        }
    }

    SyncDaemonConfig::ThrottlingLimits SyncDaemonConfig::throttlingLimits() const
    {
        ThrottlingLimits l;

        Q_D(const SyncDaemonConfig);
        QIntHash h = d->config->get_throttling_limits();
        l.upload = h.value("upload");
        l.download = h.value("download");

        return l;
    }

    void SyncDaemonConfig::setThrottlingLimits(ThrottlingLimits limits)
    {
        Q_D(SyncDaemonConfig);
        if (limits.download == 0) {
            limits.download = -1;
        }
        if (limits.upload == 0) {
            limits.upload = -1;
        }
        d->config->set_throttling_limits(limits.download, limits.upload);
    }
} // namespace UbuntuOne
