/*
  Copyright © 2010 Harald Sitter <apachelogger@ubuntu.com>

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
  published by the Free Software Foundation; either version 2 of
  the License or (at your option) version 3 or any later version
  accepted by the membership of KDE e.V. (or its successor approved
  by the membership of KDE e.V.), which shall act as a proxy
  defined in Section 14 of version 3 of the license.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef U1_KDE_SYNCDAEMONCONFIG_H
#define U1_KDE_SYNCDAEMONCONFIG_H

#include <QtCore/QObject>

#include "Export.h"

namespace UbuntuOne {
    class SyncDaemonConfigPrivate;

    /**
      Interface to manage SyncDaemon configurations.
    */
    class U1_KDE_EXPORT SyncDaemonConfig : public QObject
    {
    public:
        /**
          POD for throttling (bandwith restrictions).
        */
        struct ThrottlingLimits
        {
            int upload;
            int download;
        };

        explicit SyncDaemonConfig(QObject *parent = 0);
        ~SyncDaemonConfig();

        /**
          Check whether file sync is enabled.

          @return true if file sync is enabled.
        */
        bool fileSync() const;

        /**
          Set whether file sync is enabled.

          @param sync whether to sync
        */
        void setFileSync(bool sync);

        /**
          Check whether bandwith throttling is enabled.

          @return true if throttling is enabled.
        */
        bool isThrottling() const;

        /**
          Set whether bandwith throttling is enabled.

          @param throttle whether to trottle
        */
        void setThrottling(bool throttle);

        /**
          Returns the throttling limits in bytes/s.

          @return struct of throttling limits, if -1 the limit is not set
        */
        ThrottlingLimits throttlingLimits() const;

        /**
          Sets the throttling limits.

          @param limits new limits to set
        */
        void setThrottlingLimits(ThrottlingLimits limits);

    protected:
        SyncDaemonConfigPrivate *const d_ptr;

    private:
        Q_DISABLE_COPY(SyncDaemonConfig)
        Q_DECLARE_PRIVATE(SyncDaemonConfig)
    };
} // namespace UbuntuOne

#endif // SYNCDAEMONCONFIG_H
