/*
  Copyright © 2010 Harald Sitter <apachelogger@ubuntu.com>

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
  published by the Free Software Foundation; either version 2 of
  the License or (at your option) version 3 or any later version
  accepted by the membership of KDE e.V. (or its successor approved
  by the membership of KDE e.V.), which shall act as a proxy
  defined in Section 14 of version 3 of the license.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "SyncDaemonFilesystem.h"

#include <KFileItem>

#include "SyncDaemonDBus.h"

namespace UbuntuOne {

    class SyncDaemonFilesystemPrivate
    {
    public:
        SyncDaemonFilesystemPrivate() {}

        ~SyncDaemonFilesystemPrivate()
        {
            delete fs;
        }

        ComUbuntuoneSyncDaemonFileSystemInterface *fs;

        UbuntuOne::FileState parseFileState(const QStringHash &hash) const
        {
            if (hash["local_hash"] == hash["server_hash"]) {
                return UpdatedFileState;
            } else if (hash["server_hash"].isEmpty()) {
                return NeedsUploadFileState;
            } else {
                return NeedsUpdateFileState;
            }

            return UnknownFileState;
        }
    };

    SyncDaemonFilesystem::SyncDaemonFilesystem(QObject *parent) :
            QObject(parent),
            d_ptr(new SyncDaemonFilesystemPrivate)
    {
        Q_D(SyncDaemonFilesystem);
        d->fs =
                new ComUbuntuoneSyncDaemonFileSystemInterface("com.ubuntuone.SyncDaemon",
                                                              "/filesystem", QDBusConnection::sessionBus(),
                                                              this);
    }

    SyncDaemonFilesystem::~SyncDaemonFilesystem()
    {
    }

    UbuntuOne::FileState SyncDaemonFilesystem::fileState(const KFileItem &item)
    {
        Q_D(SyncDaemonFilesystem);
        return d->parseFileState(d->fs->get_metadata(item.url().toLocalFile()));
    }

} // namespace UbuntuOne
