/*
  Copyright © 2010 Harald Sitter <apachelogger@ubuntu.com>

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
  published by the Free Software Foundation; either version 2 of
  the License or (at your option) version 3 or any later version
  accepted by the membership of KDE e.V. (or its successor approved
  by the membership of KDE e.V.), which shall act as a proxy
  defined in Section 14 of version 3 of the license.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef U1_KDE_SYNCDAEMONFILESYSTEM_H
#define U1_KDE_SYNCDAEMONFILESYSTEM_H

#include <QtCore/QObject>

#include "Export.h"

class KFileItem;

namespace UbuntuOne {

    /**
      States a file item can have
    */
    enum FileState {
        UnknownFileState, /**< File state is not known */
        UpdatedFileState, /**< File is up-to-date */
        NeedsUpdateFileState, /**< A more recent version is available on the server */
        NeedsUploadFileState /**< The local version needs to be uploaded to the server */
    };

    class SyncDaemonFilesystemPrivate;

    class U1_KDE_EXPORT SyncDaemonFilesystem : public QObject
    {
        Q_OBJECT

    public:
        explicit SyncDaemonFilesystem(QObject *parent = 0);
        virtual ~SyncDaemonFilesystem();

    public Q_SLOTS:
        /**
          Get current state of file item.

          @param item File to get state for.

          @return File item's state.
        */
        UbuntuOne::FileState fileState(const KFileItem &item);

    protected:
        SyncDaemonFilesystemPrivate *const d_ptr;

    private:
        Q_DISABLE_COPY(SyncDaemonFilesystem);
        Q_DECLARE_PRIVATE(SyncDaemonFilesystem);
    };

} // namespace UbuntuOne

#endif // SYNCDAEMONFILESYSTEM_H
