/*
  Copyright © 2010 Harald Sitter <apachelogger@ubuntu.com>

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
  published by the Free Software Foundation; either version 2 of
  the License or (at your option) version 3 or any later version
  accepted by the membership of KDE e.V. (or its successor approved
  by the membership of KDE e.V.), which shall act as a proxy
  defined in Section 14 of version 3 of the license.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "SyncDaemonShares.h"

#include "SyncDaemonDBus.h"

namespace UbuntuOne {
    class SyncDaemonSharesPrivate
    {
    public:
        ComUbuntuoneSyncDaemonSharesInterface *shares;
    };

    SyncDaemonShares::SyncDaemonShares(QObject *parent) :
            QObject(parent),
            d_ptr(new SyncDaemonSharesPrivate)
    {
        Share::registerMetaType();
        Q_D(SyncDaemonShares);
        d->shares =
                new ComUbuntuoneSyncDaemonSharesInterface ("com.ubuntuone.SyncDaemon",
                    "/shares", QDBusConnection::sessionBus(), 0);

        connect(d->shares, SIGNAL(NewShare(UbuntuOne::Share)),
                this, SIGNAL(newShare(UbuntuOne::Share)));
        connect(d->shares, SIGNAL(ShareAnswerResponse(UbuntuOne::Share)),
                this, SIGNAL(shareAnswerRepsone(UbuntuOne::Share)));
        connect(d->shares, SIGNAL(ShareChanged(UbuntuOne::Share)),
                this, SIGNAL(shareChanged(UbuntuOne::Share)));
        connect(d->shares, SIGNAL(ShareCreated(UbuntuOne::Share)),
                this, SIGNAL(shareCreated(UbuntuOne::Share)));
        connect(d->shares, SIGNAL(ShareCreatedError(UbuntuOne::Share)),
                this, SIGNAL(shareCreateError(UbuntuOne::Share,QString)));
        connect(d->shares, SIGNAL(ShareDeleted(UbuntuOne::Share)),
                this, SIGNAL(shareRemoved(UbuntuOne::Share)));
        connect(d->shares, SIGNAL(ShareDeleteError(UbuntuOne::Share,QString)),
                this, SIGNAL(shareRemoveError(UbuntuOne::Share,QString)));
    }

    SyncDaemonShares::~SyncDaemonShares()
    {
        delete d_ptr;
    }

    void SyncDaemonShares::share(const QString &path, const QStringList &contacts,
                                 const QString &name, Share::Access accessLevel) const
    {
        qDebug() << path;
        qDebug() << contacts;
        qDebug() << name;

        Q_D(const SyncDaemonShares);
        d->shares->create_shares(path, contacts, name, Share::accessToString(accessLevel));
    }

    ShareList SyncDaemonShares::shares() const
    {
        Q_D(const SyncDaemonShares);
        return d->shares->get_shares();
    }

    QStringList SyncDaemonShares::sharesFolders() const
    {
        Q_D(const SyncDaemonShares);
        const ShareList shareList = d->shares->get_shares();
        QStringList out;
        foreach(const Share &s, shareList) {
            qDebug() << s.path();
            out << s.path();
        }
        return out;
    }

    ShareList SyncDaemonShares::shared() const
    {
        Q_D(const SyncDaemonShares);
        return d->shares->get_shared();
    }

    QStringList SyncDaemonShares::sharedFolders() const
    {
        Q_D(const SyncDaemonShares);
        const ShareList shareList = d->shares->get_shared();
        QStringList out;
        foreach(const Share &s, shareList) {
            qDebug() << s.path();
            out << s.path();
        }
        return out;
    }

    void SyncDaemonShares::accept(const QString &shareId)
    {
        Q_D(SyncDaemonShares);
        d->shares->accept_share(shareId);
    }

    void SyncDaemonShares::reject(const QString &shareId)
    {
        Q_D(SyncDaemonShares);
        d->shares->reject_share(shareId);
    }

    void SyncDaemonShares::remove(const QString &shareId)
    {
        Q_D(SyncDaemonShares);
        d->shares->delete_share(shareId);
    }

    void SyncDaemonShares::refreshShareList() const
    {
        Q_D(const SyncDaemonShares);
        d->shares->refresh_shares();
    }

} // namespace UbuntuOne
