/*
  Copyright © 2010 Harald Sitter <apachelogger@ubuntu.com>

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
  published by the Free Software Foundation; either version 2 of
  the License or (at your option) version 3 or any later version
  accepted by the membership of KDE e.V. (or its successor approved
  by the membership of KDE e.V.), which shall act as a proxy
  defined in Section 14 of version 3 of the license.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "widget.h"

#include <Plasma/ToolTipManager>

#include <QtGui/QPainter>

#include "SyncDaemon.h"

namespace UbuntuOne
{
    PlasmaWidget::PlasmaWidget(QObject *parent, const QVariantList &args) :
        Plasma::PopupApplet(parent, args),
        m_state(Disconnected),
        m_icon("ubuntuone-kde")
    {
        resize(100, 100);
        d = new SyncDaemon(this);

        connect(d, SIGNAL(disconnected()), SLOT(setDisconnected()));
        connect(d, SIGNAL(idle()), SLOT(setConnected()));

        d->updateStatus();
    }

    void PlasmaWidget::init()
    {
        // tooltip stuff
        Plasma::ToolTipContent toolTipData = Plasma::ToolTipContent();
        toolTipData.setAutohide(true);
        toolTipData.setMainText(name());
        toolTipData.setImage(m_icon);

        Plasma::ToolTipManager::self()->registerWidget(this);
        Plasma::ToolTipManager::self()->setContent(this, toolTipData);
    }

    PlasmaWidget::~PlasmaWidget()
    {
    }

    void PlasmaWidget::paintInterface(QPainter *p,
                                      const QStyleOptionGraphicsItem *option,
                                      const QRect &contentsRect)
    {
        Q_UNUSED(option);

        p->setRenderHint(QPainter::SmoothPixmapTransform);
        p->setRenderHint(QPainter::Antialiasing);

        p->drawPixmap(7, 0,
                      m_icon.pixmap((int)contentsRect.width(),
                                    (int)contentsRect.width() - 14));
        p->save();
        p->setPen(Qt::black);

        QString text;

        switch (m_state) {
        case Disconnected: text = i18nc("@info:status Disconnected from the server",
                                            "Disconnected :("); break;
        case Connected: text = i18nc("@info:status Connected to the server",
                                         "Connected :D"); break;
        }

        p->drawText(contentsRect, Qt::AlignBottom | Qt::AlignHCenter, text);
        p->restore();

    }

    void PlasmaWidget::setDisconnected()
    {
        m_state = Disconnected;
        update();
    }

    void PlasmaWidget::setConnected()
    {
        m_state = Connected;
        update();
    }

} // namespace UbuntuOne

#include "widget.moc"
