/*
  Copyright © 2010 Harald Sitter <apachelogger@ubuntu.com>

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
  published by the Free Software Foundation; either version 2 of
  the License or (at your option) version 3 or any later version
  accepted by the membership of KDE e.V. (or its successor approved
  by the membership of KDE e.V.), which shall act as a proxy
  defined in Section 14 of version 3 of the license.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef CONTACTSELECTOR_H
#define CONTACTSELECTOR_H

#include <QWidget>

namespace Akonadi
{
    class ContactsTreeModel;
    class ChangeRecorder;
    class EntityTreeView;
    class Session;
}

namespace UbuntuOne {

    /**
      Widget for letting the user select a contact from any available Akonadi
      Contacts/Addressbook resource.

      All you need to do is add the ContactSelector to a dialog and properly
      hook up with the itemSelected() signal and the addresses() slot.

      A good example would be a dialog where progression is conditional to
      having at least one contact selected. You could archive this by connecting
      itemSelected() with a slot in your dialog that calls addresses() and if
      that does not return an empty list enables the dialog's "Next" button.
    */
    class ContactSelector : public QWidget
    {
        Q_OBJECT

    public:
        explicit ContactSelector(QWidget *parent = 0);
        ~ContactSelector();

    signals:
        /**
          This signal is emitted when the user selects an item in the contacts
          view.
        */
        void itemSelected();

    public slots:
        /**
          Return ready to go email addresses.

          This will return the primary email addresses of all currently selected
          contacts. If only one contact is selected and her primary email
          address is not set an empty string list is returned. Same goes for
          when no contact is selected.

          It is a very good idea to only call this function if itemSelected()
          was emitted, since this is a somewhat meaningful indication that an
          item was selected.

          @return @c list of email addresses
          @return @c empty string list
        */
        QStringList addresses() const;

    private:
        Akonadi::ChangeRecorder *m_changeRecorder;
        Akonadi::Session *m_session;
        Akonadi::ContactsTreeModel *m_model;
        Akonadi::EntityTreeView *m_view;
    };
} // namespace UbuntuOne
#endif // CONTACTSELECTOR_H
