/*
  Copyright © 2010 Harald Sitter <apachelogger@ubuntu.com>

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
  published by the Free Software Foundation; either version 2 of
  the License or (at your option) version 3 or any later version
  accepted by the membership of KDE e.V. (or its successor approved
  by the membership of KDE e.V.), which shall act as a proxy
  defined in Section 14 of version 3 of the license.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef SHAREDIALOG_H
#define SHAREDIALOG_H

#include <KAssistantDialog>

class KDirSelectDialog;

namespace UbuntuOne {
    class ContactSelector;
    class SharePropertiesWidget;
    class SyncDaemonFolders;

    /**
      A ShareDialog to help the user create a new Ubuntu One share.
    */
    class ShareDialog : public KAssistantDialog
    {
        Q_OBJECT

    public:
        ShareDialog();
        ~ShareDialog();

    public slots:
        /**
          Overloads KAssistantDialog's next() function.

          This overload makes it condition to proceed to not have done anything
          foolish on the current dialog page. For example if the user selected
          an unsynchronized folder she will only be able to proceed if she
          agrees to adding the folder to Ubuntu One first.

          Should all conditions be matched this function will proceed to the
          next page and update buttons to match its content.
        */
        virtual void next();

        /**
          Update the "Next" button's status.

          This function either enables or disables the "Next" button dependin on
          its current page and the content on that page.
        */
        void updateNextButton();

        /**
          Enables or disables the Share button depending on whether all
          information for sharing are avilable.

          @param string name of the share, if empty the Share button will be
                 disabled
        */
        void updateShareButton(const QString &string);

        /**
          Delegate actual share creation to the SyncDaemon.

          All information will be brought into appropriate forms and sent to the
          SyncDaemon for execution.

          If necessary this will first add a new folder to Ubuntu One so it
          can be shared. Please note that this will be done in a blocking manner
          and only ends once the unsetWaiting() slot has been called.
        */
        void share();

    private slots:
        /**
          Stop waiting for the SyncDaemon to do things.

          This slot is called to stop blocking waiting operations.
        */
        void unsetWaiting();

    private:
        SyncDaemonFolders *m_folders;
        KDirSelectDialog *m_dirSelect;
        ContactSelector *m_contactSelector;
        SharePropertiesWidget *m_shareProperties;
        QString m_newFolder;
        bool m_waiting;

        bool canProceed();
    };
} // namespace UbuntuOne

#endif // SHAREDIALOG_H
