/*
  Copyright © 2010 Harald Sitter <apachelogger@ubuntu.com>

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
  published by the Free Software Foundation; either version 2 of
  the License or (at your option) version 3 or any later version
  accepted by the membership of KDE e.V. (or its successor approved
  by the membership of KDE e.V.), which shall act as a proxy
  defined in Section 14 of version 3 of the license.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef SHAREPROPERTIESWIDGET_H
#define SHAREPROPERTIESWIDGET_H

#include <QtGui/QWidget>

#include "SyncDaemonShares.h"

class KLineEdit;

namespace UbuntuOne {

    namespace Ui {
        class SharePropertiesWidget;
    }

    /**
      KDE widget for displaying and letting the user edit Ubuntu One Share
      properties.

      The widget defaults to no name (empty) and an access value of read-only.
    */
    class SharePropertiesWidget : public QWidget
    {
        Q_OBJECT

    public:
        explicit SharePropertiesWidget(QWidget *parent = 0);
        ~SharePropertiesWidget();

        /**
          Convenience function around nameLine(), returning the value from the
          line.

          @return value of nameLine()
        */
        QString name() const;

        /**
          Return the line object used to display/edit the name of the share.

          @return KLineEdit instance used for the share name
        */
        KLineEdit *nameLine() const;

        /**
          Get current selected access type of share.

          @return selected access type
        */
        Share::Access access() const;

    private:
        Ui::SharePropertiesWidget *ui;
    };

} // namespace UbuntuOne
#endif // SHAREPROPERTIESWIDGET_H
