/*
  Copyright © 2009-2010 Harald Sitter <apachelogger@ubuntu.com>

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License as
  published by the Free Software Foundation; either version 2 of
  the License or (at your option) version 3 or any later version
  accepted by the membership of KDE e.V. (or its successor approved
  by the membership of KDE e.V.), which shall act as a proxy
  defined in Section 14 of version 3 of the license.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef STATUSNOTIFIER_H
#define STATUSNOTIFIER_H

#include <KStatusNotifierItem>

#include "Types.h"

class KWebView;

namespace UbuntuOne
{
    class SyncDaemon;

    class StatusNotifier : public KStatusNotifierItem
    {
        Q_OBJECT
    public:
        /**
          Constructor.

          @param parent Parent of this object.
        */
        explicit StatusNotifier(QObject *parent = 0);

        /**
          Destructor.
        */
        virtual ~StatusNotifier();

    public slots:
        /*
          Reimplemented.
        */
        virtual void activate(const QPoint &pos = QPoint());

    private slots:
        /**
          Ask user whether to continue autostarting and then quit (unless user
          aborts).
        */
        void maybeQuit();

        /**
          Authentication failed.
        */
        void setAuthFailed();

        /**
          Currently trying to connect.
        */
        void setConnecting();

        /**
          Triggered when capabilities to server did not match.
        */
        void setCapabilityMismatch();

        /**
          SyncDaemon got disconnected.
        */
        void setDisconnected();

        /**
          Fatal error occurred.
        */
        void setFatalError();

        /**
          Idle.
        */
        void setIdle();

        /**
          Called when the U1 queue changed. This function takes appropriate
          action depend on the queue count.

          @param queueCount Count of items in the queue (i.e. length)
        */
        void updateState(int queueCount);

        /**
          Set upload status.

          @param files the files thare are currently being uploaded
          @param queue amount of transfers to do
        */
        void setUploadStatus(const QStringList &files, int queue);

        /**
          Set download status.

          @param files the files thare are currently being downloaded
          @param queue amount of transfers to do
        */
        void setDownloadStatus(const QStringList &files, int queue);

        /**
          Launch Ubuntu One KCM
        */
        static void launchConfig();

        /**
          Launch Ubuntu One Share
        */
        static void launchShare();

    private:
        /**
          DBus adaptor interface for the SyncDaemon.
        */
        UbuntuOne::SyncDaemon *d;

        /**
          Whether an upload or download is in progress.
        */
        bool m_working;

        /**
          Website of Ubuntu One.
        */
        KWebView *m_view;
    };
}

#endif // STATUSNOTIFIER_H
